# klldFN v2.8.9


# Installing
```
pip install klldFN
pip3 install klldFN
```

[![Downloads](https://static.pepy.tech/badge/klldFN)](https://pepy.tech/project/klldFN)
[![Downloads](https://static.pepy.tech/badge/klldFN/month)](https://pepy.tech/project/klldFN)
[![Downloads](https://static.pepy.tech/badge/klldFN/week)](https://pepy.tech/project/klldFN)